use crate::robot::robot_manager::RobotManager;
use log::info;
use prost::Message;
use raas_types::raas;
use raas_types::raas::cmd::Request;
use raas_types::raas::ping::Ping;
use raas_types::raas::{recv_raas_msg, send_raas_msg};
use std::time::Duration;
use tokio::io::duplex;

mod robot;

#[tokio::main]
async fn main() {
    env_logger::init();
    info!("Starting...");

    let (mut main_stream, manager_stream) = duplex(10);
    let mut manager = RobotManager::new("0.0.0.0:8080", manager_stream);

    manager.start_manager().await.unwrap();

    loop {
        info!("Sleeping");
        tokio::time::sleep(Duration::from_secs(5)).await;
        info!("Sending Ping");

        let ping = Ping {
            data: "ping msg".to_string(),
        };

        let req = Request {
            timestamp: 0,
            cmd: Some(raas::cmd::request::Cmd::RollCmd(raas::bot::roll::RollCmd {
                cmd: Some(raas::bot::roll::roll_cmd::Cmd::Ping(ping)),
            })),
        };

        let mut msg = Vec::new();

        req.encode(&mut msg).unwrap();

        send_raas_msg(&mut main_stream, msg).await.unwrap();

        info!("Wait for resp");
        let resp = recv_raas_msg(&mut main_stream).await.unwrap();

        info!("Got resp {:?}", resp);
    }
}
